AnyEncode

Trait AnyEncode 

pub trait AnyEncode<'q>:
    Encode<'q, Postgres>
    + Type<Postgres>
    + Encode<'q, MySql>
    + Type<MySql>
    + Encode<'q, Mssql>
    + Type<Mssql>
    + Encode<'q, Sqlite>
    + Type<Sqlite> { }
Available on crate feature any and (crate features mssql or mysql or postgres or sqlite) only.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'q, T> AnyEncode<'q> for T
where T: Encode<'q, Postgres> + Type<Postgres> + Encode<'q, MySql> + Type<MySql> + Encode<'q, Mssql> + Type<Mssql> + Encode<'q, Sqlite> + Type<Sqlite>,

Available on crate features mssql and mysql and postgres and sqlite only.