[−][src]Module sqlx_core::connection
Traits
| Connect | Represents a type that can directly establish a new connection. |
| Connection | Represents a single database connection rather than a pool of database connections. |
| Connect | Represents a type that can directly establish a new connection. |
| Connection | Represents a single database connection rather than a pool of database connections. |