Module types

Module types 

Conversions between Rust and SQL types.

To see how each SQL type maps to a Rust type, see the corresponding types module for each database:

Any external types that have had Type implemented for, are re-exported in this module for convenience as downstream users need to use a compatible version of the external crate to take advantage of the implementation.

Nullable

To represent nullable SQL types, Option<T> is supported where T implements Type. An Option<T> represents a potentially NULL value from SQL.

Structs

Text
Map a SQL text value to/from a Rust type using Display and FromStr.

Traits

Type
Indicates that a SQL type is supported for a database.